; ====================================================;
;                                                     ;
;       hid.inc for EC v2 Fasm classic projects       ;
;                   (version 1.0.0)                   ;
;                                                     ;
;            Copyright  Ramon Sala - 2022            ;
;                                                     ;
; ====================================================;

if ~defined HID_INC
define HID_INC 1

DATA_SIZE_MASK                                  equ     003H
TYPE_MASK                                       equ     00CH
TAG_MASK                                        equ     0F0H

DATA_SIZE_0                                     equ     000H
DATA_SIZE_1                                     equ     001H
DATA_SIZE_2                                     equ     002H
DATA_SIZE_4                                     equ     003H

TYPE_MAIN                                       equ     000H
TYPE_GLOBAL                                     equ     004H
TYPE_LOCAL                                      equ     008H

TAG_MAIN_INPUT                                  equ     080H
TAG_MAIN_OUTPUT                                 equ     090H
TAG_MAIN_COLLECTION                             equ     0A0H
TAG_MAIN_FEATURE                                equ     0B0H
TAG_MAIN_ENDCOLLECTION                          equ     0C0H

TAG_GLOBAL_USAGEPAGE                            equ     000H
TAG_GLOBAL_LOGICALMIN                           equ     010H
TAG_GLOBAL_LOGICALMAX                           equ     020H
TAG_GLOBAL_PHYSMIN                              equ     030H
TAG_GLOBAL_PHYSMAX                              equ     040H
TAG_GLOBAL_UNITEXP                              equ     050H
TAG_GLOBAL_UNIT                                 equ     060H
TAG_GLOBAL_REPORTSIZE                           equ     070H
TAG_GLOBAL_REPORTID                             equ     080H
TAG_GLOBAL_REPORTCOUNT                          equ     090H
TAG_GLOBAL_PUSH                                 equ     0A0H
TAG_GLOBAL_POP                                  equ     0B0H

TAG_LOCAL_USAGE                                 equ     000H
TAG_LOCAL_USAGEMIN                              equ     010H
TAG_LOCAL_USAGEMAX                              equ     020H

HID_GET_REPORT                                  equ     001H
HID_GET_IDLE                                    equ     002H
HID_GET_PROTOCOL                                equ     003H
HID_SET_REPORT                                  equ     009H
HID_SET_IDLE                                    equ     00AH
HID_SET_PROTOCOL                                equ     00BH

HID_HID_DESCRIPTOR_TYPE                         equ     021H
HID_REPORT_DESCRIPTOR_TYPE                      equ     022H
HID_PHYSICAL_DESCRIPTOR_TYPE                    equ     023H

HID_SUBCLASS_NONE                               equ     0
HID_SUBCLASS_BOOT_INTERFACE                     equ     1

HID_PROTOCOL_NONE                               equ     000H
HID_PROTOCOL_KEYBOARD                           equ     001H
HID_PROTOCOL_MOUSE                              equ     002H

HID_BOOT_PROTOCOL                               equ     000H
HID_RPT_PROTOCOL                                equ     001H

HID_REPORT_TYPE_INPUT                           equ     1
HID_REPORT_TYPE_OUTPUT                          equ     2
HID_REPORT_TYPE_FEATURE                         equ     3

HID_REQUEST_GET_REPORT                          equ     001H
HID_REQUEST_GET_IDLE                            equ     002H
HID_REQUEST_GET_PROTOCOL                        equ     003H
HID_REQUEST_SET_REPORT                          equ     009H
HID_REQUEST_SET_IDLE                            equ     00AH
HID_REQUEST_SET_PROTOCOL                        equ     00BH

HID_DESCRIPTOR_HID                              equ     021H
HID_DESCRIPTOR_REPORT                           equ     022H
HID_DESRIPTOR_PHY                               equ     023H

HID_INTF                                        equ     003H

HID_BOOT_INTF_SUBCLASS                          equ     001H


HID_ITEM_TYPE_MAIN                              equ     0
HID_ITEM_TYPE_GLOBAL                            equ     1
HID_ITEM_TYPE_LOCAL                             equ     2
HID_ITEM_TYPE_RESERVED                          equ     3

HID_LONG_ITEM_PREFIX                            equ     0FEH

bmHID_MAIN_ITEM_TAG                             equ     0FCH

bmHID_MAIN_ITEM_INPUT                           equ     080H
bmHID_MAIN_ITEM_OUTPUT                          equ     090H
bmHID_MAIN_ITEM_COLLECTION                      equ     0A0H
bmHID_MAIN_ITEM_FEATURE                         equ     0B0H
bmHID_MAIN_ITEM_END_COLLECTION                  equ     0CEH

HID_MAIN_ITEM_COLLECTION_PHYSICAL               equ     0
HID_MAIN_ITEM_COLLECTION_APPLICATION            equ     1
HID_MAIN_ITEM_COLLECTION_LOGICAL                equ     2
HID_MAIN_ITEM_COLLECTION_REPORT                 equ     3
HID_MAIN_ITEM_COLLECTION_NAMED_ARRAY            equ     4
HID_MAIN_ITEM_COLLECTION_USAGE_SWITCH           equ     5
HID_MAIN_ITEM_COLLECTION_USAGE_MODIFIER         equ     6


;========================================  Functions ======================================;
import hid,\
    HidD_FlushQueue,'HidD_FlushQueue',\
    HidD_FreePreparsedData,'HidD_FreePreparsedData',\
    HidD_GetAttributes,'HidD_GetAttributes',\
    HidD_GetConfiguration,'HidD_GetConfiguration',\
    HidD_GetFeature,'HidD_GetFeature',\
    HidD_GetHidGuid,'HidD_GetHidGuid',\
    HidD_GetIndexedString,'HidD_GetIndexedString',\
    HidD_GetInputReport,'HidD_GetInputReport',\
    HidD_GetManufacturerString,'HidD_GetManufacturerString',\
    HidD_GetMsGenreDescriptor,'HidD_GetMsGenreDescriptor',\
    HidD_GetNumInputBuffers,'HidD_GetNumInputBuffers',\
    HidD_GetPhysicalDescriptor,'HidD_GetPhysicalDescriptor',\
    HidD_GetPreparsedData,'HidD_GetPreparsedData',\
    HidD_GetProductString,'HidD_GetProductString',\
    HidD_GetSerialNumberString,'HidD_GetSerialNumberString',\
    HidD_Hello,'HidD_Hello',\
    HidD_SetConfiguration,'HidD_SetConfiguration',\
    HidD_SetFeature,'HidD_SetFeature',\
    HidD_SetNumInputBuffers,'HidD_SetNumInputBuffers',\
    HidD_SetOutputReport,'HidD_SetOutputReport',\
    HidP_GetButtonArray,'HidP_GetButtonArray',\
    HidP_GetButtonCaps,'HidP_GetButtonCaps',\
    HidP_GetCaps,'HidP_GetCaps',\
    HidP_GetData,'HidP_GetData',\
    HidP_GetExtendedAttributes,'HidP_GetExtendedAttributes',\
    HidP_GetLinkCollectionNodes,'HidP_GetLinkCollectionNodes',\
    HidP_GetScaledUsageValue,'HidP_GetScaledUsageValue',\
    HidP_GetSpecificButtonCaps,'HidP_GetSpecificButtonCaps',\
    HidP_GetSpecificValueCaps,'HidP_GetSpecificValueCaps',\
    HidP_GetUsageValue,'HidP_GetUsageValue',\
    HidP_GetUsageValueArray,'HidP_GetUsageValueArray',\
    HidP_GetUsages,'HidP_GetUsages',\
    HidP_GetUsagesEx,'HidP_GetUsagesEx',\
    HidP_GetValueCaps,'HidP_GetValueCaps',\
    HidP_InitializeReportForID,'HidP_InitializeReportForID',\
    HidP_MaxDataListLength,'HidP_MaxDataListLength',\
    HidP_MaxUsageListLength,'HidP_MaxUsageListLength',\
    HidP_SetButtonArray,'HidP_SetButtonArray',\
    HidP_SetData,'HidP_SetData',\
    HidP_SetScaledUsageValue,'HidP_SetScaledUsageValue',\
    HidP_SetUsageValue,'HidP_SetUsageValue',\
    HidP_SetUsageValueArray,'HidP_SetUsageValueArray',\
    HidP_SetUsages,'HidP_SetUsages',\
    HidP_TranslateUsagesToI8042ScanCodes,'HidP_TranslateUsagesToI8042ScanCodes',\
    HidP_UnsetUsages,'HidP_UnsetUsages',\
    HidP_UsageListDifference,'HidP_UsageListDifference'


;======================= Undocumented functions (unknown arguments) =======================;
;if defined APP_WIN64
;    extrn '__imp_HidP_GetVersionInternal' as HidP_GetVersionInternal:qword
;else
;    extrn '__imp__HidP_GetVersionInternal@??' as HidP_GetVersionInternal:dword
;end if

end if ;HID_INC
